# Windows Git 1.3.5
(Windows Glk 1.47)

Windows Git is an interpreter for Glulx games. Windows Git consists of a core interpreter called Git, and an input/output library, called Windows Glk. Together these two components form the Windows Git package, which has been created by David Kinder.
Web: http://www.davidkinder.co.uk/
Email: davidk@davidkinder.co.uk

Git's main goal in life is to be fast. It's about five times faster than Glulxe, and about twice as fast as Frotz (using the same Inform source compiled for the Z-machine). It also tries to be reasonably careful with memory: it's possible to trade speed off against memory by changing the sizes of Git's internal buffers. Git was written so that people would be able to write huge games or try out complicated algorithms without worrying about how fast their games are going to run.

The latest release of Windows Git is available from the Git page at the IF Archive, which also contains many games that can be played with Windows Git. For help on how to get started with Windows Git, click here.

Windows Git supports all the features of the Glk and Blorb specifications, including graphics (with alpha blending and gamma correction) and sound (as either samples or music). Windows Git is based on Windows Glk by David Kinder and Git by Iain Merrick. Windows Glk and Git are released under these licenses.